@@ -4,6 +4,7 @@ function(Data,Prior,Mcmc)
 # 
 # revision history:
 #          P. Rossi 1/17/05
+#          3/07 added classes
 # Purpose:
 #   perform Gibbs iterations for Univ Regression Model using
 #     prior with beta, sigma-sq indep
@@ -50,7 +51,7 @@ if(nobs != nrow(X) ) {pandterm("length(y) ne nrow(X)")}
 # check for Prior
 #
 if(missing(Prior))
-   { betabar=c(rep(0,nvar)); A=.01*diag(nvar)}
+   { betabar=c(rep(0,nvar)); A=.01*diag(nvar); nu=3; ssq=var(y)}
 else
    {
     if(is.null(Prior$betabar)) {betabar=c(rep(0,nvar))} 
@@ -138,6 +139,10 @@ for (rep in 1:Mcmc$R)
 ctime = proc.time()[3]
 cat('  Total Time Elapsed: ',round((ctime-itime)/60,2),'\n')
 
+attributes(betadraw)$class=c("bayesm.mat","mcmc")
+attributes(betadraw)$mcpar=c(1,R,keep)
+attributes(sigmasqdraw)$class=c("bayesm.mat","mcmc")
+attributes(sigmasqdraw)$mcpar=c(1,R,keep)
 
 return(list(betadraw=betadraw,sigmasqdraw=sigmasqdraw))
 }
